.. _androidinstall:

Installation on Android
=======================

Kivy is a Python framework, and simply installing it on an Android
device the same way as on a desktop machine will do nothing. However,
you can compile a Kivy application to a standard Android APK that will
run just like a normal java app on (more or less) any device.

We provide several different tools to help you run code on an Android
device, covered fully in the :doc:`Android packaging documentation
</guide/packaging-android>`. These include creating a fully standalone APK
that may be released on an Android store, as well as the ability to
run your Kivy apps without a compilation step using our pre-prepared
Kivy Launcher app.
